==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingDescription } from "./RingDescription";
/**
 * @hidden
 */
export let RingDescriptionMetadata = /*@__PURE__*/ (() => {
    class RingDescriptionMetadata extends Base {
        static b(a) {
            if (RingDescriptionMetadata.a == null) {
                RingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RingDescriptionMetadata.c(RingDescriptionMetadata.a);
            }
            if (a.j(RingDescriptionMetadata.a)) {
                return;
            }
            a.y(RingDescriptionMetadata.a);
            RingSeriesBaseDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("InnerExtend", "Number:double");
            a.item("ControlSize", "Size");
            a.item("Center", "Point");
            a.item("RingSeries", "ExportedType:RingSeriesBase");
            a.item("RingBreadth", "Number:double");
        }
        static d(a) {
            RingDescriptionMetadata.b(a);
            a.aa("Ring", () => new RingDescription());
            a.z("Ring", RingDescriptionMetadata.a);
        }
    }
    RingDescriptionMetadata.$t = /*@__PURE__*/ markType(RingDescriptionMetadata, 'RingDescriptionMetadata');
    RingDescriptionMetadata.a = null;
    return RingDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingDescription } from "./RingDescription";
/**
 * @hidden
 */
export let RingDescriptionMetadata = /*@__PURE__*/ (() => {
    class RingDescriptionMetadata extends Base {
        static b(a) {
            if (RingDescriptionMetadata.a == null) {
                RingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RingDescriptionMetadata.c(RingDescriptionMetadata.a);
            }
            if (a.k(RingDescriptionMetadata.a)) {
                return;
            }
            a.aa(RingDescriptionMetadata.a);
            RingSeriesBaseDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("InnerExtend", "Number:double");
            a.item("ControlSize", "Size");
            a.item("Center", "Point");
            a.item("RingSeries", "ExportedType:RingSeriesBase");
            a.item("RingBreadth", "Number:double");
        }
        static d(a) {
            RingDescriptionMetadata.b(a);
            a.ac("Ring", () => new RingDescription());
            a.ab("Ring", RingDescriptionMetadata.a);
        }
    }
    RingDescriptionMetadata.$t = /*@__PURE__*/ markType(RingDescriptionMetadata, 'RingDescriptionMetadata');
    RingDescriptionMetadata.a = null;
    return RingDescriptionMetadata;
})();
